@@ -3,13 +3,11 @@ import sys
 
 from .display import Display
 from .keyboard import Keyboard
-from .keyboard.key import Keys
+from .keyboard.key import keys
 from .mouse import Mouse
 
 __all__ = ['sm', 'keys']
 
-keys = Keys()
-
 
 class Simulant:
     def __init__(self):
