@@ -25,7 +25,7 @@ class Display:
         self.current_screen = self.screens[0]
 
     def screen(self, number):
-        return [i for i in self.screens if i.screen.number == number]
+        return [i for i in self.screens if i.number == number][0]
 
     @property
     def dsp(self):
