@@ -8,12 +8,16 @@ class Screen(Shell):
 
     def __init__(self, number):
         self.number = number
-        self.focus_window = [window for window in self.windows if window.is_focus][0]  # todo change focus
 
-    def get_window(self, class_name):
-        window = Window(class_name=class_name)
-        self.window.append(window)
-        return window
+    @property
+    def focus_window(self):
+        return [window for window in self.windows if window.is_focus][0]  # todo change focus
+
+    def get_windows(self, class_name):
+        windows_ids = self.execute(f"xdotool search --classname --onlyvisible {class_name}")
+        windows_obj = [Window(window_id) for window_id in windows_ids]
+        self.windows.extend(windows_obj)
+        return windows_obj
 
     @staticmethod
     def is_select():  # todo check xdotool
