@@ -1,5 +1,8 @@
 import re
+
 from simulant.os import Shell
+from simulant.keyboard.key import keys
+
 
 
 class Location(Shell):
@@ -62,10 +65,9 @@ class Size(Shell):
 
 
 class Window(Shell):
-    def __init__(self, class_name=None, location_x=None, location_y=None, width=None, height=None):
-        if class_name is not None:
-            self.id = self._id_by_class(class_name)
-        self.focus()
+    def __init__(self, id, location_x=None, location_y=None, width=None, height=None):
+        self.id = id
+        self.focus()  # todo focus unfocused
         self.location = Location(self.id, location_x, location_y)
         self.size = Size(self.id, width, height)
         self._update_geometry()
@@ -77,19 +79,30 @@ class Window(Shell):
     def focus(self):
         self.execute(f"xdotool windowfocus {self.id}")
 
-    def _id_by_class(self, class_name):
-        return self.execute(f"xdotool search --classname --onlyvisible {class_name}")
-
     position_pattern = re.compile(r"^Position: (\d+),(\d+) \(screen: (\d+)\)$")
     geometry_pattern = re.compile(r"^Geometry: (\d+)x(\d+)$")
 
     def _update_geometry(self):
         output = self.execute(f"xdotool getwindowgeometry {self.id}")
-        _, position, geometry = output.split('\n')
-        position_result = re.search(self.position_pattern, position.strip())
-        geometry_result = re.search(self.geometry_pattern, geometry.strip())
+        _, position, geometry = output
+        position_result = re.search(self.position_pattern, position)
+        geometry_result = re.search(self.geometry_pattern, geometry)
         self.screen = int(position_result.group(3))
         self.location.x = int(position_result.group(1))
         self.location.y = int(position_result.group(2))
         self.size.width = int(geometry_result.group(1))
         self.size.height = int(geometry_result.group(2))
+
+    def close(self):
+        self.focus()
+        self.execute(keys.CTRL + keys.F4)
+
+    @property
+    def name(self):
+        return self.execute(f'xdotool getwindowname {self.id}')
+
+    def __str__(self):
+        return f"<Window: {self.name}>"
+
+    def __repr__(self):
+        return self.__str__()
